#!/bin/sh
# Licensed Materials - Property of IBM
# 5648-F10 (C) Copyright International Business Machines Corp. 2005, 2007 
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# traps the SIGTTOU command that might be thrown if the user invokes
# ./launchpad.sh &
trap '' 22
    
    supportedMozillaVersion() {
 case "$*" in
     *rv:1.[7-9]*) return 0;;
     *rv:[2-9].[0-9]*) return 0;;
     *rv:*) return 1;;
     Mozilla\ 1.[7-9]*) return 0;;
     Mozilla\ [2-9].[0-9]*) return 0;;       
       SeaMonkey\ 1.[0-9]*) return 0;;
       SeaMonkey\ [2-9].[0-9]*) return 0;;
     *) return 1;;
 esac
    }

    supportedFirefoxVersion() {
 case "$*" in
            *Firefox\ [1-9].*) return 0;;
     *Firefox/[1-9].*) return 0;;
            *Firefox*) return 1;;
            *rv:1.[7-9]*) return 0;;
            *rv:[2-9].*) return 0;;
     *rv:*) return 1;;
     Mozilla*\ 1.[7-9]*) return 0;;
     Mozilla*\ [2-9].[0-9]*) return 0;;
     *) return 1;;
 esac
    }

    supportedSeaMonkeyVersion()
    {
      case "$*" in
         SeaMonkey\ 1.[0-9]*) return 0;;
         SeaMonkey\ [2-9].[0-9]*) return 0;;        
         *) return 1;;
      esac
    }

    whichBrowser=NoBrowser
    case "$0" in
        /*) fullpath=$0;;
         *) fullpath=`pwd`/$0;;
    esac
    installsourcepath=`echo "$fullpath" | sed "s,/\./,/,g; s,/[^/][^/]*/\.\./,/,g; s,//,/,g; s,/[^/]*$,,"`

    if [ -z "$LaunchPadContentDir" ]; then
        LaunchPadContentDir=content/
        export LaunchPadContentDir
    fi

    #cross platform way to see if the launchpadEnv file exists (-e doesn't work on solaris)
    ls "$installsourcepath/launchpad/launchpadEnv" > /dev/null 2>&1 
    if [ $? -eq 0 ]; then    
        #while read k v; eval $k=$v; export $k; done < "$installsourcepath/launchpad/launchpadEnv"
 while read key value
 do
   #don't set variables that are already defined 
   if [ "$key" ]; then
     #Ensure the line is somewhat well formed by checking that a value is also specified     
     if [ "$value" ];  then   
       eval $key=$value
       export $key
     fi
   fi
        done < $installsourcepath/launchpad/launchpadEnv  
    fi

    #If BROWSER isn't set, check LaunchPadDefaultBrowser
    if [ -z "$BROWSER" ]; then
      if [ "$LaunchPadDefaultBrowser" ]; then 
        #First see if LaunchPadDefaultBrowser needs to be translated from one of the supported values
        if [ $LaunchPadDefaultBrowser = "MozillaHTML" ]; then
          LaunchPadDefaultBrowser=mozilla;
        fi
        if [ $LaunchPadDefaultBrowser = "Mozilla" ]; then
          LaunchPadDefaultBrowser=mozilla;
        fi
        if [ $LaunchPadDefaultBrowser = "FirefoxHTML" ]; then
          LaunchPadDefaultBrowser=firefox;
        fi
        if [ $LaunchPadDefaultBrowser = "Firefox" ]; then
          LaunchPadDefaultBrowser=firefox;
        fi
        if [ $LaunchPadDefaultBrowser = "SeaMonkeyHTML" ]; then
          LaunchPadDefaultBrowser=seamonkey;
        fi
        if [ $LaunchPadDefaultBrowser = "SeaMonkey" ]; then
          LaunchPadDefaultBrowser=seamonkey;
        fi
        #Finally, set the browser
        BROWSER=$LaunchPadDefaultBrowser; export BROWSER;
      fi
    fi

    if [ "$BROWSER" ]; then
        if versionString=`("$BROWSER" -version) 2>/dev/null`; then
            case "$versionString" in
     *Firefox*) if supportedFirefoxVersion "$versionString"; then
                           whichBrowser=Firefox
                   fi ;;
     *Mozilla*) if supportedMozillaVersion "$versionString"; then
                           whichBrowser=Mozilla
                   fi ;;
            *SeaMonkey*) if supportedSeaMonkeyVersion "$versionString"; then
                             whichBrowser=SeaMonkey
                   fi ;;
            esac
        fi
    fi
    
    if [ $whichBrowser = NoBrowser ]; then
      PATH="$PATH:/usr/X11R6/bin:/usr/local/bin:/usr/bin:/opt/mozilla:/usr/mozilla:/usr/sfw/lib/mozilla";export PATH
        if versionString=`(mozilla -version) 2>/dev/null`; then
          BROWSER=mozilla; export BROWSER
          if supportedMozillaVersion "$versionString"; then
            whichBrowser=Mozilla
          fi
       fi
    fi

    if [ $whichBrowser = NoBrowser ]; then
      PATH="$PATH:/opt/firefox:/usr/firefox:/usr/firefox/sfw/lib/firefox";export PATH
        if versionString=`(firefox -version) 2>/dev/null`; then
          BROWSER=firefox; export BROWSER
          if supportedFirefoxVersion "$versionString"; then
            whichBrowser=Firefox
          fi
       fi
    fi
    
    if [ $whichBrowser = NoBrowser ]; then
      PATH="$PATH:/usr/X11R6/bin:/usr/local/bin:/usr/bin:/opt/seamonkey:/usr/seamonkey:/usr/sfw/lib/mozilla:/usr/local/seamonkey/";export PATH
        if versionString=`(seamonkey -version) 2>/dev/null`; then
          BROWSER=seamonkey; export BROWSER
          if supportedSeaMonkeyVersion "$versionString"; then
            whichBrowser=SeaMonkey
          fi
       fi
    fi
    
    LaunchPadArch=`$installsourcepath/launchpad/SetArchitecture.sh`
    export LaunchPadArch

    if [ $whichBrowser = Firefox ]; then
        launchpadShell=`$installsourcepath/launchpad/CheckShell.sh`
    else
        launchpadShell="sh"
    fi

    if [ $launchpadShell = sh ]; then
      eval $* exec $installsourcepath/launchpad/$whichBrowser.sh 
    elif [ $launchpadShell = bash ]; then
       if [ $whichBrowser = NoBrowser ]; then
         eval $* exec $installsourcepath/launchpad/$whichBrowser.sh
       else
         eval $* exec $installsourcepath/launchpad/"$whichBrowser"_bash.sh
       fi
    else
        exec $installsourcepath/launchpad/NoBrowser.sh
    fi

